# Datalang
Datalang it's an easy to use language with a similar syntax to YAML.<br>
It has a fast parser!

# How-to Install
You will need **GIT** or **PIP**
```sh
pip install datalang
# Or
git clone https://github.com/zsendokame/datalang; cd datalang; python setup.py
```

# How-to Use
```

```